======================================
README for HydraTK TrackApps extension
======================================

| TrackApps extension provides interface to bugtracking and test management applications.

| Following applications are supported.

* Quality Center - bugtracking, test management
* Bugzilla - bugtracking
* Mantis - bugtracking
* Trac - bugtracking
* Jira - bugtracking
* TestLink - test management